      SUBROUTINE MOUT (NOUT,NR,M,N,A)
C
C     *****PARAMETERS:
      INTEGER NOUT,NR,M,N
      DOUBLE PRECISION A(NR,N)
C
C     *****LOCAL VARIABLES:
      INTEGER I,J
C
C     *****FORTRAN FUNCTIONS:
C     NONE
C
C     *****SUBROUTINES CALLED:
C     NONE
C
C     ------------------------------------------------------------------
C
C     *****PURPOSE:
C     THIS SUBROUTINE WRITES OUT AN M BY N MATRIX A BY ROWS IN FREE
C     FORMAT ON THE DEVICE SPECIFIED BY NOUT.
C
C     *****PARAMETER DESCRIPTION:
C
C     ON INPUT:
C
C       NOUT    INTEGER
C               THE DEVICE NUMBER OF THE OUTPUT DEVICE;
C
C       NR      INTEGER
C               ROW DIMENSION OF THE ARRAY CONTAINING THE MATRIX A
C               AS DECLARED IN THE MAIN CALLING PROGRAM DIMENSION
C               STATEMENT;
C
C       M       INTEGER
C               NUMBER OF ROWS OF THE MATRIX A;
C
C       N       INTEGER
C               NUMBER OF COLUMNS OF THE MATRIX A;
C
C       A       REAL(NR,N)
C               MATRIX TO BE WRITTEN OUT.
C
C     *****ALGORITHM NOTES:
C     NONE
C
C     *****HISTORY:
C     THIS SUBROUTINE WAS WRITTEN BY W.F. ARNOLD, NAVAL WEAPONS CENTER,
C     CODE 35104, CHINA LAKE, CA  93555, AS PART OF THE SOFTWARE PACKAGE
C     RICPACK, SEPTEMBER 1983.
C
C     ------------------------------------------------------------------
C
      DO 10 I=1,M
          WRITE(NOUT,*) (A(I,J),J=1,N)
   10 CONTINUE
      RETURN
C
C     LAST LINE OF MOUT
C
      END
